@@ -6,6 +6,8 @@
 # -------------------------------------------------------------------------------
 """Contains the RequireSignedCommits object."""
 
+import textwrap
+
 from RepoAuditor.Plugins.GitHub.Impl.EnableRulesetRequirementImpl import EnableRulesetRequirementImpl
 
 
@@ -19,7 +21,19 @@ class RequireSignedCommits(EnableRulesetRequirementImpl):
             dynamic_arg_name="no",
             github_ruleset_type="required_signatures",
             github_ruleset_value="Require signed commits",
-            get_configuration_value_func=lambda rule: rule.get("type", "") == "required_signatures",
-            resolution="{__enabled_str} commit signing requirement in repository rulesets",
-            rationale="Signed commits ensure commit authenticity",
+            get_configuration_value_func=self._GetValue,
+            rationale=textwrap.dedent(
+                """\
+                The default behavior is to require signed commits. Note that this setting does not work with
+                rebase merging or squash merging.
+
+                Reasons for this Default
+                ------------------------
+                - Ensure that the author of a commit is who the claim to be.
+
+                Reasons to Override this Default
+                --------------------------------
+                - You have enabled rebase merging or squash merging.
+                """,
+            ),
         )
