@@ -37,7 +37,7 @@ class TestEnsureStatusChecks:
 
     def test_disabled(self, requirement, query_data):
         """Test disabled requirement"""
-        requirement_args = {"disabled": True}
+        requirement_args = {"no": True}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.DoesNotApply
         assert "The status check requirement has been explicitly disabled." in result.context
@@ -45,7 +45,7 @@ class TestEnsureStatusChecks:
     def test_required_status_checks_missing(self, requirement, query_data):
         """Test when `required_status_checks` is missing"""
         query_data["branch_protection_data"] = {}
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.DoesNotApply
         assert result.context is None
@@ -53,7 +53,7 @@ class TestEnsureStatusChecks:
     def test_required_status_checks_none(self, requirement, query_data):
         """Test when `required_status_checks` is None"""
         query_data["branch_protection_data"] = {"required_status_checks": None}
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.DoesNotApply
         assert result.context is None
@@ -61,7 +61,7 @@ class TestEnsureStatusChecks:
     def test_checks_missing(self, requirement, query_data):
         """Test when `checks` is missing"""
         query_data["branch_protection_data"]["required_status_checks"] = {}
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
         assert "No status checks are configured." in result.context
@@ -69,7 +69,7 @@ class TestEnsureStatusChecks:
     def test_checks_none(self, requirement, query_data):
         """Test when `checks` is None"""
         query_data["branch_protection_data"]["required_status_checks"] = {"checks": None}
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
         assert "No status checks are configured." in result.context
@@ -77,15 +77,15 @@ class TestEnsureStatusChecks:
     def test_Successful(self, requirement, query_data):
         """Test successful"""
         query_data["branch_protection_data"]["required_status_checks"]["checks"] = ["check1", "check2"]
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Success
 
     def test_SuccessfulGetDynamicArgDefinitions(self, requirement, query_data):
         """Test with GetDynamicArgDefinitions"""
         query_data["branch_protection_data"]["required_status_checks"]["checks"] = ["check1", "check2"]
-        requirement_args = {}
-        for key, value in requirement.GetDynamicArgDefinitions().items():
+        requirement_args = {"no": False}
+        for key, value in requirement.GetDynamicArgDefinitions("-").items():
             requirement_args[key] = value[1].default
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Success
