@@ -74,6 +74,6 @@ class TestRequireApprovalMostRecentPush:
         query_data["branch_protection_data"]["required_pull_request_reviews"][
             "require_last_push_approval"
         ] = True
-        requirement_args = {"disabled": False}
+        requirement_args = {"no": False}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Success
