@@ -18,7 +18,7 @@ class TestEnableRulesetRequirementImpl:
         requirement = EnableRulesetRequirementImpl(
             name="Test Name",
             enabled_by_default=False,
-            dynamic_arg_name="enabled",
+            dynamic_arg_name="yes",
             github_ruleset_type="Test Ruleset",
             github_ruleset_value="test_ruleset",
             get_configuration_value_func=lambda _: True,
@@ -28,7 +28,7 @@ class TestEnableRulesetRequirementImpl:
 
         assert requirement.name == "Test Name"
         assert requirement.enabled_by_default is False
-        assert requirement.dynamic_arg_name == "enabled"
+        assert requirement.dynamic_arg_name == "yes"
         assert requirement.github_ruleset_type == "Test Ruleset"
 
     def test_Evaluate_Disabled(self):
@@ -36,7 +36,7 @@ class TestEnableRulesetRequirementImpl:
         requirement = EnableRulesetRequirementImpl(
             name="Test Name",
             enabled_by_default=False,
-            dynamic_arg_name="enabled",
+            dynamic_arg_name="yes",
             github_ruleset_type="Test Ruleset",
             github_ruleset_value="test_ruleset",
             get_configuration_value_func=lambda _: True,
@@ -44,7 +44,7 @@ class TestEnableRulesetRequirementImpl:
             rationale="Test rationale",
         )
         query_data = {}
-        requirement_args = {"enabled": False}
+        requirement_args = {"yes": False}
         result = requirement.Evaluate(query_data, requirement_args)
         # No rule and should be disabled, hence result is success
         assert result.result == EvaluateResult.Success
@@ -56,7 +56,7 @@ class TestEnableRulesetRequirementImpl:
         requirement = EnableRulesetRequirementImpl(
             name="True By Default",
             enabled_by_default=True,
-            dynamic_arg_name="disabled",
+            dynamic_arg_name="no",
             github_ruleset_type="Test Ruleset",
             github_ruleset_value="test_ruleset",
             get_configuration_value_func=lambda rule: rule.get("type", "") == "valid_rule",
@@ -74,7 +74,7 @@ class TestEnableRulesetRequirementImpl:
                 },
             ]
         }
-        requirement_args = {"disabled": True}
+        requirement_args = {"no": True}
         result = requirement.Evaluate(query_data, requirement_args)
         # No rule and should be disabled, hence result is success
         assert result.result == EvaluateResult.Error
@@ -85,7 +85,7 @@ class TestEnableRulesetRequirementImpl:
         requirement = EnableRulesetRequirementImpl(
             name="Test Name",
             enabled_by_default=False,
-            dynamic_arg_name="enabled",
+            dynamic_arg_name="yes",
             github_ruleset_type="Test Ruleset",
             github_ruleset_value="test_ruleset",
             get_configuration_value_func=lambda rule: rule.get("type", "") == "valid rule",
@@ -103,7 +103,7 @@ class TestEnableRulesetRequirementImpl:
                 },
             ]
         }
-        requirement_args = {"enabled": True}
+        requirement_args = {"yes": True}
         result = requirement.Evaluate(query_data, requirement_args)
         assert result.result == EvaluateResult.Error
 
@@ -112,7 +112,7 @@ class TestEnableRulesetRequirementImpl:
         requirement = EnableRulesetRequirementImpl(
             name="Test Name",
             enabled_by_default=False,
-            dynamic_arg_name="enabled",
+            dynamic_arg_name="yes",
             github_ruleset_type="Test Ruleset",
             github_ruleset_value="test_ruleset",
             get_configuration_value_func=lambda rule: rule.get("type", "") == "valid_rule",
@@ -130,7 +130,7 @@ class TestEnableRulesetRequirementImpl:
                 }
             ]
         }
-        requirement_args = {"enabled": True}
+        requirement_args = {"yes": True}
         result = requirement.Evaluate(query_data, requirement_args)
 
         assert result.result == EvaluateResult.Success
